@@ -8,8 +8,19 @@ from django.conf import settings
 from .. import VERSION
 from ..auth import ApiAuth
 
-class APIView( View ):
+
+class APIProtectedView( View ):
 	
+	def dispatch( self, request, *args, **kwargs ):
+		self.params = getattr( request, request.method )
+		api_auth = ApiAuth( self.get_secret() )
+		if not api_auth.is_valid( self.params.get('token') ):
+			raise PermissionDenied( 'Your key didn\'t fit' )
+		return super(APIProtectedView, self).dispatch(request, *args, **kwargs)
+				
+	def get_secret( self ):
+		return self.secret
+		
 	def get_values( self ):
  		return json.loads( self.params.get( 'values' ) )
 
@@ -20,15 +31,12 @@ class APIView( View ):
 
 	def OK( self, data ):
 		return self.response( 200, data )
+		
+		
+class ServiceView( APIProtectedView ):
 
-class APIProtectedView( APIView ):
-	
-	def dispatch( self, request, *args, **kwargs ):
-		self.params = getattr( request, request.method )
-		api_auth = ApiAuth( self.get_secret() )
-		if not api_auth.is_valid( self.params.get('token') ):
-			raise PermissionDenied( 'Your key didn\'t fit' )
-		return super(APIProtectedView, self).dispatch(request, *args, **kwargs)
-				
-	def get_secret( self ):
-		return self.secret
\ No newline at end of file
+	def get( self, request, *args, **kwargs ):
+		return self.OK( {'version':VERSION, 'services':self.get_services()} )
+		
+	def get_services( self ):
+		return self.services
